/****************************************************************************
 *
 * Filename:    adc16.h (Windows version)
 * Copyright:   Pico Technology Limited 1994-1998
 *              www.picotech.com
 * Author:      Mike Green
 * Description:
 * This header defines the interface to driver routines for the PICO ADC-16.
 *
 * Revision Info: "file %n date %f revision %v"
 *                "file ADC16.H date 3-Feb-97,14:26:52 revision 1"
 *
 ****************************************************************************/

/* C++ needs different prefixes for the declarations...
 */

#ifdef __cplusplus
#define PREF1 extern "C"
#else
#define PREF1
#endif


#ifdef WIN32
#define PREF2 __declspec(dllexport) __stdcall
#define MAX_ADC16_UNITS         20
#elif defined (WINDOWS)
#define PREF2 __pascal __export
#define MAX_ADC16_UNITS         9

#elif defined (DOS)
#define PREF2 far pascal
#define MAX_ADC16_UNITS         4
#else
#error Operating system not defined
#endif



        /* adc16_get_driver_version
         *
         * Call this routine to check that the driver version is recent
         *
         * accepts:
         *     nothing
         *
         * returns:
         *     high byte: major version
         *     low byte: minor version
         *
         */

PREF1 short  PREF2  adc16_get_driver_version (void);

        /* adc16_poll
         *
         * Call this routine to poll
         *
         */
PREF1 void PREF2 adc16_poll
        (
        void
        );


#if defined (WINDOWS) || defined(WIN32)
        /* adc16_open_unit
         *
         * Call this routine to specify the port and interrupt
         *
         * port = 1..4
         *
         */
PREF1  short PREF2 adc16_open_unit
        (
        unsigned short port
        );
#else
        /* adc16_open_unit
         *
         * Call this routine to specify the port and interrupt
         *
         * port = 1..4
         * base = base address, eg 0x3F8 ... 0 for default
         * irq = 1..15 or 0 for default
         *
         */
PREF1  short PREF2 adc16_open_unit
        (
        unsigned short port,
        unsigned short base_address,
        unsigned short irq
        );
#endif

        /* adc16_driver_close_unit
         *
         * Call this routine once only to close
         *
         */
PREF1  void PREF2 adc16_close_unit
        (
        unsigned short port
        );

                /* adc16_set_channel
                 *
                 * Set the resolution and single/dual for a channel
                 *
                 */


PREF1  short PREF2  adc16_set_channel
        (
        unsigned short   port,
        unsigned short   channel,
        unsigned short   resolution,
        unsigned short   single_ended,
        unsigned short    filter_factor
        );


        /* adc16_get_value
         *
         * This routine gets the most recent reading from the adc
         *
         */
PREF1  short PREF2  adc16_get_value
        (
        long far *      value,
        unsigned short             port,
        unsigned short             channel
        );

        /* adc16_get_filtered_value
         *
         * This routine gets the most recent reading from the adc
         *
         */
PREF1  short PREF2  adc16_get_filtered_value
        (
        long far *      value,
        unsigned short             port,
        unsigned short             channel
        );

        /* adc16_get_version
         *
         * This routine gets the version from the unit for a specified channel
         *
         */

PREF1  short PREF2  adc16_get_version
        (
        unsigned short far *      version,
        unsigned short            port
        );

        /* adc16_update_filters
         *
         * This routine re-initialises the filters for all active channels
         *
         */

PREF1  void PREF2  adc16_update_filters
        (
        void
        );

        /* adc16_get_cycle
         *
         * This routines the number of complete measurement cycles
         *  that the specified unit has been through
         */
PREF1  short PREF2 adc16_get_cycle (unsigned long far * cycle,
                                                                unsigned short port);

#define CHANNELS_PER_ADC16 8




