/**************************************************************************
 *
 * Project:     adc16
 *
 * Filename:    main.c
 *
 * Copyright:   Pico Technology Limited 1996
 *
 * Author:      Mike Green
 *
 * Description:
 *   This file contains the main data display program
 *
 * History:
 *  26Feb96 MKG Created
 *
 * Revision Info: "file %n date %f revision %v"
 *                "file ADC16TES.C date 29-Aug-96,15:29:08 revision 1"
 *
 ***************************************************************************/

#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dos.h>
#include <assert.h>

#define WINDOWS
#include "adc16.h"
#include "adc16tes.rch"

#define ID_TIMER 	1
#define NO_OF_CHANNELS	4

static HINSTANCE   hInstance;
LRESULT CALLBACK WndProc (HWND, UINT, WPARAM, LPARAM) ;

short   port;
short   opened;
HWND    hMain;

/****************************************************************************
 *
 *
 ****************************************************************************/

LRESULT CALLBACK  WndProc (HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
{
  int			c;
  long          	value;
  char 			str [80];
  static BOOL		in_timer;
  BOOL			ok;
  unsigned short 	version;

  switch (message)
    {
    case WM_USER:
    if (!opened)
      {
      wsprintf (str, "Unit COM%d not opened", port);
      }
    else
      {
      adc16_get_version (&version, port);
      version &= 0xFF;
      wsprintf (str, "Unit opened on COM%d\r\nVersion %d.%d\r\n", port, version / 10, version % 10);
      }
    SetDlgItemText (hwnd, IDC_STATUS, str);
    break;

    case WM_TIMER:
    if (!in_timer)
      {
      in_timer = TRUE;
        for (c = 0; c < NO_OF_CHANNELS; c++)
          {
          ok = adc16_get_value (&value, port, c+1);
          if(ok)
            {
            wsprintf (str, "%ld", value);
            }
          else
            {
            strcpy (str, "");
            }
          SetDlgItemText (hwnd, IDC_VALUE1 + c, str);
          }
      in_timer = FALSE;
      }
    return 0;


    case WM_DESTROY:
    adc16_close_unit (port);
    KillTimer (hwnd, ID_TIMER);
    PostQuitMessage (0) ;
    return 0 ;
    }

  return DefWindowProc (hwnd, message, wParam, lParam) ;
}

/****************************************************************************
 *
 *
 ****************************************************************************/

int __stdcall WinMain (
  HINSTANCE hInst,
  HINSTANCE hPrevInstance,
  LPSTR lpszCmdLine,
  int nCmdShow)

{
  static char 	szClass [] = "A16DEMO";
  MSG         	msg;
  WNDCLASS    	wndclass ;
  int           c;


  hInstance = hInst;

  if (!hPrevInstance)
        {
        wndclass.style          = CS_HREDRAW | CS_VREDRAW;
        wndclass.lpfnWndProc    = WndProc;
        wndclass.cbClsExtra     = 0 ;
        wndclass.cbWndExtra     = DLGWINDOWEXTRA ;
        wndclass.hInstance      = hInstance;
	wndclass.hIcon          = NULL;
        wndclass.hCursor        = LoadCursor (NULL, IDC_ARROW) ;
        wndclass.hbrBackground  = (HBRUSH) (COLOR_WINDOW + 1);
        wndclass.lpszMenuName   = NULL ;
        wndclass.lpszClassName  = szClass ;

        RegisterClass (&wndclass) ;

        }

  port = 1;

  opened  = adc16_open_unit (port);
  for (c = 1; c <= NO_OF_CHANNELS; c++)
    {
    opened &= adc16_set_channel (port, c, 16, FALSE, 10);
    }

  hMain = CreateDialog (hInstance, MAKEINTRESOURCE (IDD_MAIN), 0, NULL) ;
  ShowWindow (hMain, nCmdShow) ;

  SendMessage (hMain, WM_USER, 0, 0L);

  SetTimer (hMain, ID_TIMER, 1000, NULL);

  while (GetMessage (&msg, NULL, 0, 0))
        {
        TranslateMessage (&msg) ;
        DispatchMessage (&msg) ;
	}

  adc16_close_unit (port);

  return (int) msg.wParam ;
}


