/**
 * Copyright (c) 1999, 2000 Gatespace AB. All Rights Reserved.
 * 
 */

package com.gatespace.service.adc.impl;

import java.util.*;
import java.io.*;
import javax.comm.*;

import com.gatespace.service.adc.*;

/**
 * Test class for ADCServiceImpl and ADC16LowLevel classes.
 *
 * <p>
 * Source to <a href="Main.java">Main.java</a><br>
 *
 * @version  $Revision: 1.8 $
 */
public class Main {
  /**
   * Opens a serial port and tries to read data from attached ADC16.
   *
   * @param argv argv[0] is used as port name.
   */
  public static void main(String[] argv) {

    try {
      if(argv.length < 1) {
	error("No port name specified");
	return;
      }

      String portName = argv[0];
      
      CommPortIdentifier commPortIdentifier = null;
      
      try {
	commPortIdentifier = 
	  CommPortIdentifier.getPortIdentifier(portName);
      } catch (NoSuchPortException e) {
	error("No port " + portName);
	return;
      }
      
      if (commPortIdentifier.getPortType() != CommPortIdentifier.PORT_SERIAL) {
	error("Port is not a serial port: " + portName);
	return;
      }
      if (commPortIdentifier.isCurrentlyOwned()) {
	error("Port is owned by " + 
	      commPortIdentifier.getCurrentOwner() + 
	      ": " + portName);
	return;
      }
      
      SerialPort port = 
	(SerialPort)commPortIdentifier.open("Serial", 1000);
      
      ADCServiceImpl adc = new ADCServiceImpl(port, new ADC16LowLevel());
      adc.start();

      ADCTester tester = new ADCTester();
      tester.test(adc);

    } catch (Exception e) {
      e.printStackTrace();
    }
  }
  
  static void error(String s) {
    System.err.println("error: " + s);
  }
}
